package com.chinaitop.depot.intelligent.basicdata.model;

import java.math.BigDecimal;
import java.util.Date;

public class TWarningThreshold {
    private String id;

    private String orgId;

    private String vCfCode;

    private String wModule;

    private String wName;

    private Integer wState;

    private BigDecimal threshold;

    private String wUpdatePerson;

    private Date wUpdateTime;

    private Integer delFlag;

    /**
     * 32位唯一编码
     * @return id 32位唯一编码
     */
    public String getId() {
        return id;
    }

    /**
     * 32位唯一编码
     * @param id 32位唯一编码
     */
    public void setId(String id) {
        this.id = id == null ? null : id.trim();
    }

    /**
     * 库点标识
     * @return org_id 库点标识
     */
    public String getOrgId() {
        return orgId;
    }

    /**
     * 库点标识
     * @param orgId 库点标识
     */
    public void setOrgId(String orgId) {
        this.orgId = orgId == null ? null : orgId.trim();
    }

    /**
     * 仓房编码
     * @return v_cf_code 仓房编码
     */
    public String getvCfCode() {
        return vCfCode;
    }

    /**
     * 仓房编码
     * @param vCfCode 仓房编码
     */
    public void setvCfCode(String vCfCode) {
        this.vCfCode = vCfCode == null ? null : vCfCode.trim();
    }

    /**
     * 所属模块名称
     * @return w_module 所属模块名称
     */
    public String getwModule() {
        return wModule;
    }

    /**
     * 所属模块名称
     * @param wModule 所属模块名称
     */
    public void setwModule(String wModule) {
        this.wModule = wModule == null ? null : wModule.trim();
    }

    /**
     * 预警名称
     * @return w_name 预警名称
     */
    public String getwName() {
        return wName;
    }

    /**
     * 预警名称
     * @param wName 预警名称
     */
    public void setwName(String wName) {
        this.wName = wName == null ? null : wName.trim();
    }

    /**
     * 是否开启
     * @return w_state 是否开启
     */
    public Integer getwState() {
        return wState;
    }

    /**
     * 是否开启
     * @param wState 是否开启
     */
    public void setwState(Integer wState) {
        this.wState = wState;
    }

    /**
     * 预警阈值
     * @return threshold 预警阈值
     */
    public BigDecimal getThreshold() {
        return threshold;
    }

    /**
     * 预警阈值
     * @param threshold 预警阈值
     */
    public void setThreshold(BigDecimal threshold) {
        this.threshold = threshold;
    }

    /**
     * 创建人
     * @return w_update_person 创建人
     */
    public String getwUpdatePerson() {
        return wUpdatePerson;
    }

    /**
     * 创建人
     * @param wUpdatePerson 创建人
     */
    public void setwUpdatePerson(String wUpdatePerson) {
        this.wUpdatePerson = wUpdatePerson == null ? null : wUpdatePerson.trim();
    }

    /**
     * 创建时间
     * @return w_update_time 创建时间
     */
    public Date getwUpdateTime() {
        return wUpdateTime;
    }

    /**
     * 创建时间
     * @param wUpdateTime 创建时间
     */
    public void setwUpdateTime(Date wUpdateTime) {
        this.wUpdateTime = wUpdateTime;
    }

    /**
     * 删除标志（0：删除，1：未删除）
     * @return del_flag 删除标志（0：删除，1：未删除）
     */
    public Integer getDelFlag() {
        return delFlag;
    }

    /**
     * 删除标志（0：删除，1：未删除）
     * @param delFlag 删除标志（0：删除，1：未删除）
     */
    public void setDelFlag(Integer delFlag) {
        this.delFlag = delFlag;
    }
}