package com.chinaitop.depot.intelligent.utils;

import com.chinaitop.depot.intelligent.basicdata.model.TWarningThreshold;
import com.chinaitop.depot.intelligent.grainsituation.model.TWarningThresholdHistory;
import org.springframework.stereotype.Component;

import java.math.BigDecimal;
import java.util.Date;

@Component
public class WarningMessage {
    /**
     *
     * @param tid id
     * @param cfCdoe 仓房编码
     * @param threshold 报警实体包括orgID
     * @param tthreshold 检测值
     * @param wThreshold 预警或报警设置值
     * @param date 检测时间
     * @param desc 描述信息
     * @param dataSource 数据来源
     * @param mode 0测温，1测虫，2测气
     * @param warning 0报警，1预警
     * @return 历史报警实体
     */
    public TWarningThresholdHistory saveWThreshold(String tid,String cfCdoe, TWarningThreshold threshold, BigDecimal tthreshold, BigDecimal wThreshold, Date date, String desc, String dataSource,String mode,String warning) {
        TWarningThresholdHistory tt = new TWarningThresholdHistory();
        tt.setId(tid);
        tt.setOrgId(threshold.getOrgId());
        tt.setvCfCode(cfCdoe);
        tt.setwModule(threshold.getwModule());
        tt.setwName(threshold.getwName());
        tt.setThreshold(tthreshold);
        tt.setwThreshold(wThreshold);
        tt.setwTime(date);
        tt.setwUpdateTime(DateUtils.getDate());
        tt.setDataSource(dataSource);
        tt.setwRemark(desc);
        tt.setwMode(mode);
        tt.setwWarning(warning);
        tt.setIsSend("1");
        return tt;
    }
}
